@@ -58,7 +58,7 @@
 #
 # See recent changes in file ChangeLog
 
-$VERSION = '1.14' ;
+$VERSION = '1.15' ;
 
 # Just to make sure which file is loaded
 # BEGIN{ print "SEE THIS ???\n",`pwd` }
@@ -1487,7 +1487,7 @@ BEGIN {
     $vlist = <<EOD ; 
 
 obter: obtenho obtns obtm ivo obtm model ter 
-bster: abstenho abstns abstm ivo abstm model ter 
+abster: abstenho abstns abstm ivo abstm model ter 
 ater: atenho atns atm ivo atm model ter 
 conter: contenho contns contm ivo contm model ter 
 deter: detenho detns detm ivo detm model ter 
@@ -1565,8 +1565,8 @@ sentir:
   sinto sentes etc
   cpres sinta etc
   # HERE Must check
-  ivo sente sinta etc
-sentir = ressentir assentir consentir mentir desmentir
+  ivo sente sinta sintamos senti sintam
+sentir = ressentir assentir consentir mentir desmentir investir revestir desinvestir vestir
 ir:
   vou  vais  vai vamos ides vo ,
   fui  foste foi fomos fostes foram , 
@@ -1637,7 +1637,7 @@ ler:
   ivo   l lia leiamos leiam
 ler = reler tresler
 atribuir:
-  atribuo atribuis atribui atribumos atribuem,
+  atribuo atribuis atribui atribumos atribus atribuem,
   atribu atribuste  atribuiu  atribumos  atriburam, 
   atribua atribuas  atribua  atribuamos  atribuam, 
   cfut   atribuir . atribuir atribuirmos .
